@@ -10,7 +10,6 @@ use warnings;
 use base qw(Class::Accessor);
 use Template;
 use Template::Filters;
-use ClearPress::util;
 use Carp;
 use English qw(-no_match_vars);
 use POSIX qw(strftime);
@@ -24,7 +23,7 @@ use MIME::Base64 qw(encode_base64);
 use JSON;
 use Readonly;
 
-our $VERSION = q[2018.3.13];
+our $VERSION = q[2019.02.01];
 
 our $DEBUG_OUTPUT        = 0;
 our $DEBUG_L10N          = 0;
@@ -32,6 +31,11 @@ our $TEMPLATE_CACHE      = {};
 our $LEXICON_CACHE       = {};
 our $TRAP_REDIR_OVERFLOW = 0; # set to non-zero value to cut-off at that many bytes
 
+Readonly::Scalar our $DEFAULT_PROTO_PORTS => {
+                                              http => 80,
+                                              https => 443,
+                                             };
+
 __PACKAGE__->mk_accessors(qw(util model action aspect content_type entity_name autoescape charset decorator headers));
 
 sub new { ## no critic (Complexity)
@@ -385,6 +389,18 @@ sub process_template { ## no critic (Complexity)
   my $http_host   = ($xfh ? $xfh : $ENV{HTTP_HOST}) || q[localhost];
   my $http_port   = ($xfh ? $xfp : $ENV{HTTP_PORT}) || q[];
   my $http_proto  = $ENV{HTTP_X_FORWARDED_PROTO}    || $ENV{HTTPS}?q[https]:q[http];
+
+  #########
+  # if default port for protocol, skip addition of the port
+  #
+  for my $default_proto (keys %{$DEFAULT_PROTO_PORTS}) {
+    if(($default_proto eq lc $http_proto) &&
+       $http_port == $DEFAULT_PROTO_PORTS->{$default_proto}) {
+      $http_port = q[];
+      last;
+    }
+  }
+
   my $href        = sprintf q[%s://%s%s%s%s],
 			    $http_proto,
 			    $http_host,
@@ -476,17 +492,20 @@ sub _populate_from_cgi {
   # parse new-style POST payload
   # todo: look at PUTDATA as well
   #
-  my $postdata = $cgi->param('POSTDATA');
-  if($postdata) {
-    utf8::decode($postdata);
+  my ($method) = $ENV{REQUEST_METHOD} =~ /(PUT|POST)/smix;
+  my $PDATA    = sprintf q[%sDATA], (uc $method || 'POST');
+  my $reqdata  = $cgi->param($PDATA);
+
+  if($reqdata) {
+    utf8::decode($reqdata);
     eval {
       my $json = JSON->new->utf8;
       eval {
-        $params = $json->decode($postdata);
+        $params = $json->decode($reqdata);
         1;
 
       } or do {
-        $params = XMLin($postdata);
+        $params = XMLin($reqdata);
       };
 
       for my $k (%{$params}) {
@@ -502,7 +521,7 @@ sub _populate_from_cgi {
       #########
       # Not an XML-formatted POST body. Ignore for now.
       #
-      carp q[Got error while parsing POSTDATA: ].$EVAL_ERROR;
+      carp qq[Got error while parsing $PDATA: ].$EVAL_ERROR;
     };
   }
 
@@ -1161,8 +1180,6 @@ e.g.
 
 =item XML::Simple
 
-=item ClearPress::util
-
 =item Carp
 
 =item English
